/*
 * This file is part of the MicroPython project, http://micropython.org/
 *
 * The MIT License (MIT)
 *
 * Copyright (c) 2018 Damien P. George
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
#ifndef MICROPY_INCLUDED_STM32_QSPI_H
#define MICROPY_INCLUDED_STM32_QSPI_H

#include "drivers/bus/qspi.h"

#define QSPI_MAP_ADDR (0x90000000)
#define QSPI_MAP_ADDR_MAX (0xa0000000)

extern const mp_qspi_proto_t qspi_proto;

void qspi_init(uint8_t num_dummy);
void qspi_memory_map(void);
void qspi_memory_map_exit(void);
void qspi_memory_map_restart(void);

static inline bool qspi_is_valid_addr(uint32_t addr) {
    return QSPI_MAP_ADDR <= addr && addr < QSPI_MAP_ADDR_MAX;
}

#endif // MICROPY_INCLUDED_STM32_QSPI_H
